==> haskell-optparse-applicative-0.14.2.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.14.2.0
id: optparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx
key: optparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx
license: BSD-3-Clause
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: huw.campbell@gmail.com
author: Paolo Capriotti, Huw Campbell
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System, CLI, Options, Parsing
abi: 122fe1d9115c41827cd61505838d2602
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/optparse-applicative-0.14.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/optparse-applicative-0.14.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/optparse-applicative-0.14.2.0
hs-libraries: HSoptparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx
depends:
    base-4.11.1.0 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W process-1.6.3.0
    ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl=9d4f369601ee2b22ce73b0afa89e8002
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-applicative-0.14.2.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.14.2.0
id: optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
key: optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
license: BSD-3-Clause
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: huw.campbell@gmail.com
author: Paolo Capriotti, Huw Campbell
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System, CLI, Options, Parsing
abi: ae7f0ef22284c6d85efc629be435c88e
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/optparse-applicative-0.14.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/optparse-applicative-0.14.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/optparse-applicative-0.14.2.0
hs-libraries: HSoptparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
depends:
    base-4.11.1.0 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W process-1.6.3.0
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
